@@ -179,11 +179,13 @@ class Connection(object):
         _logger.debug("finding master")
         self.__host = None
         self.__port = None
+        sock = None
         for (host, port) in self.__nodes:
             _logger.debug("trying %r:%r" % (host, port))
             try:
                 try:
                     sock = socket.socket()
+                    sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
                     sock.settimeout(_CONNECT_TIMEOUT)
                     sock.connect((host, port))
                     sock.settimeout(None)
@@ -198,13 +200,16 @@ class Connection(object):
                             "%r claims master is %r, but that's not configured" %
                             ((host, port), master))
                     _logger.debug("not master, master is (%r, %r)" % master)
-                except socket.error:
+                except socket.error, e:
                     exctype, value = sys.exc_info()[:2]
                     _logger.debug("could not connect, got: %s %s" %
                                   (exctype, value))
+                    if len(self.__nodes) == 1:
+                        raise ConnectionFailure(e)
                     continue
             finally:
-                sock.close()
+                if sock is not None:
+                    sock.close()
         raise ConnectionFailure("could not find master")
 
     def __connect(self, socket_number):
@@ -220,6 +225,7 @@ class Connection(object):
 
         try:
             self.__sockets[socket_number] = socket.socket()
+            self.__sockets[socket_number].setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
             sock = self.__sockets[socket_number]
             sock.settimeout(_CONNECT_TIMEOUT)
             sock.connect((self.host(), self.port()))
