@@ -46,6 +46,7 @@ class Cursor(object):
 
         self.__data = []
         self.__id = None
+        self.__connection_id = None
         self.__retrieved = 0
         self.__killed = False
 
@@ -65,7 +66,10 @@ class Cursor(object):
         """Closes this cursor.
         """
         if self.__id and not self.__killed:
-            self.__collection.database().connection().close_cursor(self.__id)
+            if self.__connection_id is not None:
+                self.__collection.database().connection().close_cursor(self.__id, self.__connection_id)
+            else:
+                self.__collection.database().connection().close_cursor(self.__id)
         self.__killed = True
 
     def __query_spec(self):
@@ -203,11 +207,11 @@ class Cursor(object):
     def where(self, code):
         """Adds a $where clause to this query.
 
-        The `code` argument must be an instance of (str, unicode) containing
-        a JavaScript expression. This expression will be evaluated for each
-        object scanned. Only those objects for which the expression evaluates
-        to *true* will be returned as results. The keyword *this* refers to the
-        object currently being scanned.
+        The `code` argument must be an instance of (str, unicode, Code)
+        containing a JavaScript expression. This expression will be evaluated
+        for each object scanned. Only those objects for which the expression
+        evaluates to *true* will be returned as results. The keyword *this*
+        refers to the object currently being scanned.
 
         Raises TypeError if `code` is not an instance of (str, unicode). Raises
         InvalidOperation if this cursor has already been used. Only the last
@@ -217,10 +221,10 @@ class Cursor(object):
           - `code`: JavaScript expression to use as a filter
         """
         self.__check_okay_to_chain()
-        if not isinstance(code, types.StringTypes):
-            raise TypeError("argument to where must be one of (str, unicode)")
+        if not isinstance(code, Code):
+            code = Code(code)
 
-        self.__spec["$where"] = Code(code.encode('utf-8'))
+        self.__spec["$where"] = code
         return self
 
     def _refresh(self):
@@ -234,7 +238,16 @@ class Cursor(object):
             return len(self.__data)
 
         def send_message(operation, message):
-            response = self.__collection.database().connection()._receive_message(operation, message, _sock=self.__socket)
+            kwargs = {"_sock": self.__socket}
+            if self.__connection_id is not None:
+                kwargs["_connection_to_use"] = self.__connection_id
+
+            response = self.__collection.database().connection()._receive_message(operation, message, **kwargs)
+
+            if isinstance(response, types.TupleType):
+                (connection_id, response) = response
+            else:
+                connection_id = None
 
             response_flag = struct.unpack("<i", response[:4])[0]
             if response_flag == 1:
@@ -249,6 +262,7 @@ class Cursor(object):
                 assert response_flag == 0
 
             self.__id = struct.unpack("<q", response[4:12])[0]
+            self.__connection_id = connection_id
             assert struct.unpack("<i", response[12:16])[0] == self.__retrieved
 
             number_returned = struct.unpack("<i", response[16:20])[0]
